#   Copyright (c) 2012-2014 Tobias Leupold <tobias.leupold@web.de>
#
#   This file is part of the muckturnier package.
#
#   This program is free software; you can redistribute it and/or modify it
#   under the terms of the GNU General Public License as published by the Free
#   Software Foundation in version 2 of the License.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
#   or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
#   for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program; if not, write to the Free Software Foundation, Inc.,
#   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

import os

from PyQt5.QtCore import Qt
from PyQt5.QtGui import QFont, QPixmap
from PyQt5.QtWidgets import \
    QDialog, QWidget, QVBoxLayout, QGridLayout, QLabel, QPushButton, QSizePolicy, QGroupBox

from muckturnier.enums import MT, DB
from muckturnier.shared import shared

class AboutWindow(QDialog):

    """The 'about' window dialog."""

    def __init__(self, parent):
        """Constructs the object."""

        super().__init__(parent)

        self.setWindowTitle('Über muckturnier')

        layout = QVBoxLayout(self)

        """ icon, muckturnier version """

        headerBox = QGroupBox(self)
        headerBoxLayout = QGridLayout(headerBox)
        headerBoxLayout.setHorizontalSpacing(10)
        layout.addWidget(headerBox)

        icon = QLabel(self)
        icon.setPixmap(QPixmap(shared.absolutePath('icon.png')))
        icon.setSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum)
        headerBoxLayout.addWidget(icon, 0, 0, 2, 1)

        headerLabel = QLabel('muckturnier', self)
        headerFont = headerLabel.font()
        headerFont.setPointSize(headerFont.pointSize() * 1.5)
        headerLabel.setFont(headerFont)
        headerLabel.setTextInteractionFlags(Qt.TextSelectableByMouse)
        headerBoxLayout.addWidget(headerLabel, 0, 1, Qt.AlignBottom)

        versionLabel = QLabel('<b>{}</b>'.format(MT.muckturnierVersion), self)
        versionLabel.setTextInteractionFlags(Qt.TextSelectableByMouse)
        headerBoxLayout.addWidget(versionLabel, 1, 1, Qt.AlignTop)

        """ info """

        infoBox = QGroupBox(self)
        infoBoxLayout = QVBoxLayout(infoBox)
        layout.addWidget(infoBox)

        infoLabel = QLabel((
            '<p>'
            'muckturnier &ndash; Ein Programm zum Auswerten von Muckturnieren<br>'
            'Homepage: '
            '<a href="http://nasauber.de/opensource/muckturnier/">'
            'http://nasauber.de/opensource/muckturnier/'
            '</a>'
            '</p>'

            '<p>'
            'Veröffentlicht unter der Lizenz '
            '<a href="http://www.gnu.org/licenses/old-licenses/gpl-2.0.html">'
            'GNU GPL Version 2'
            '</a>'
            '</p>'

            '<p>'
            '© 2012&ndash;2014 Tobias Leupold '
            '<a href="mailto:tobias.leupold@web.de">&lt;tobias.leupold@web.de&gt;</a>'
            '</p>'
        ), self)
        infoLabel.setTextInteractionFlags(Qt.TextBrowserInteraction | Qt.TextSelectableByMouse)
        infoLabel.setOpenExternalLinks(True)
        infoBoxLayout.addWidget(infoLabel)

        """ close button """

        closeButton = QPushButton('Schließen', self)
        closeButton.setSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum)
        closeButton.clicked.connect(self.close)
        layout.addWidget(closeButton, 0, Qt.AlignRight)
