#   Copyright (c) 2012-2014 Tobias Leupold <tobias.leupold@web.de>
#
#   This file is part of the muckturnier package.
#
#   This program is free software; you can redistribute it and/or modify it
#   under the terms of the GNU General Public License as published by the Free
#   Software Foundation in version 2 of the License.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
#   or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
#   for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program; if not, write to the Free Software Foundation, Inc.,
#   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

import os

from PyQt5.QtCore import Qt, QDir
from PyQt5.QtWidgets import QTableWidgetItem

from muckturnier.enums import MT

class shared:

    """This holds static shared functions."""

    def simplify(string):
        """Strips whitespace from a string and compresses inner whitespace"""
        return ' '.join(string.strip().split())

    def cell(text, editable, color, textColor = None):
        """Creates a QTableWidgetItem, either editable or not, and defined colors"""
        cell = QTableWidgetItem(str(text))
        cell.setBackground(MT.rowColor[color])

        if editable == MT.notEditable:
            cell.setFlags(cell.flags() & ~Qt.ItemIsEditable)
        if textColor != None:
            cell.setForeground(textColor)

        return cell

    def boogify(score, boogerScore):
        """Returns a score with a booger symbol added if the score is the booger score"""
        score = str(score)
        if score == boogerScore:
            return score
        else:
            return '{} ●'.format(score)

    def absolutePath(fileName):
        """Creates an absolute path for a file name relative to the base directory"""
        return '{0}{1}..{1}{2}'.format(
            QDir.toNativeSeparators(os.path.dirname(os.path.realpath(__file__))),
            QDir.separator(),
            fileName
        )
